@@ -26,7 +26,7 @@
 #include <gtksourceview/gtksourceview.h>
 #include <gtksourceview/gtksourcelanguagemanager.h>
 
-#include "giggle-revision.h"
+#include "libgiggle/giggle-revision.h"
 
 G_BEGIN_DECLS
 
@@ -37,6 +37,12 @@ G_BEGIN_DECLS
 #define GIGGLE_IS_DIFF_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIGGLE_TYPE_DIFF_VIEW))
 #define GIGGLE_DIFF_VIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIGGLE_TYPE_DIFF_VIEW, GiggleDiffViewClass))
 
+enum {
+	STYLE_CHUNK,
+	STYLE_FILE,
+	STYLE_ALL,
+} giggle_diff_style;
+
 typedef struct GiggleDiffView      GiggleDiffView;
 typedef struct GiggleDiffViewClass GiggleDiffViewClass;
 
@@ -57,11 +63,22 @@ void               giggle_diff_view_set_revisions     (GiggleDiffView *diff_view
 						       GList          *files);
 void               giggle_diff_view_diff_current      (GiggleDiffView *diff_view,
 						       GList          *files);
+void               giggle_diff_view_set_current_hunk  (GiggleDiffView *diff_view,
+						       int             hunk_index);
+void               giggle_diff_view_set_current_style (GiggleDiffView *diff_view,
+						       gint            style);
+int                giggle_diff_view_get_current_hunk  (GiggleDiffView *diff_view);
 
-gboolean           giggle_diff_view_get_compact_mode  (GiggleDiffView *view);
+int                giggle_diff_view_get_current_style (GiggleDiffView *diff_view);
 
-void               giggle_diff_view_set_compact_mode  (GiggleDiffView *view,
-						       gboolean        compact_mode);
+int                giggle_diff_view_get_n_hunks       (GiggleDiffView *diff_view);
+
+void               giggle_diff_view_scroll_to_file    (GiggleDiffView *diff_view,
+						       const char     *filename);
+
+const char *       giggle_diff_view_get_current_file  (GiggleDiffView *diff_view);
+
+int                giggle_diff_view_get_current_file_nb (GiggleDiffView *diff_view);
 
 G_END_DECLS
 
