@@ -121,7 +121,8 @@ label_action_create_tool_item (GtkAction *action)
 	item = gtk_tool_item_new ();
 	label = gtk_label_new (NULL);
 
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_widget_set_halign (label, GTK_ALIGN_START);
+	gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
 	gtk_container_add (GTK_CONTAINER (item), label);
 	gtk_widget_show (label);
 
