@@ -21,8 +21,8 @@
 #ifndef __GIGGLE_REMOTE_EDITOR_H__
 #define __GIGGLE_REMOTE_EDITOR_H__
 
+#include <gtk/gtk.h>
 #include "libgiggle/giggle-remote.h"
-#include <gtk/gtkdialog.h>
 
 G_BEGIN_DECLS
 
